AttributeEnumType class final

Represents an enum type in custom attributes.

Inheritance

Constructors

AttributeEnumType()
const

Properties

code ElementType
The ElementType code corresponding to this metadata type.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited