AttributeEnumValue class final

Represents an enum value in custom attributes.

Inheritance

Constructors

AttributeEnumValue(String name, int value)
const

Properties

hashCode int
The hash code for this object.
no setteroverride
name String
The name of the enum.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MetadataType
The type of the metadata value.
finalinherited
value int
The value of the enum.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override