has method
Whether this instance has all the bit fields specified in other.
Implementation
bool has(CallingConvention other) => this & other == other;
Whether this instance has all the bit fields specified in other.
bool has(CallingConvention other) => this & other == other;