ConstPointerType class final

Represents a const pointer type.

Inheritance

Constructors

ConstPointerType(MetadataType pointee, int depth)
const

Properties

code ElementType
The ElementType code corresponding to this metadata type.
no setterinherited
depth int
The number of pointer indirections (e.g., const T** has depth 2).
final
hashCode int
The hash code for this object.
no setteroverride
pointee MetadataType
The type the pointer points to.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override