ConstReferenceType class final

Represents a const (readonly) reference type to another type.

Inheritance

Constructors

ConstReferenceType(MetadataType element)
const

Properties

code ElementType
The ElementType code corresponding to this metadata type.
no setterinherited
element MetadataType
The type of the element the const reference points to.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override