FieldRVA class final

Represents a row in the FieldRVA metadata table.

The fields are populated by interpreting the binary metadata as specified in ECMA-335 II.22.18.

The FieldRVA table has the following columns:

  • RVA (4-byte constant)
  • Field (Field Table Index)
Inheritance

Constructors

FieldRVA(MetadataIndex metadataIndex, int readerIndex, int index)

Properties

field → Field
The associated field that has an explicit RVA.
latefinal
hashCode → int
The hash code for this object.
no setterinherited
index → int
The index of the row within the metadata table, starting from zero.
finalinherited
metadataIndex → MetadataIndex
The metadata index for the current row.
finalinherited
reader → MetadataReader
The metadata reader for this row.
finalinherited
readerIndex → int
The reader index used to access a specific metadata reader.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rva → int
The relative virtual address (RVA) within the image file where the field's data is stored.
latefinal
table → MetadataTable
The metadata table associated with this row.
no setteroverride
token → int
The metadata token for this row, which is a unique identifier for the row within the metadata table.
no setteroverride

Methods

decode<T extends CodedIndex>(int column) → T
Decodes a CodedIndex from the specified column.
inherited
getEqualRange<L extends Row>(int column, int value) → Iterable<L>
Retrieves rows of L with a matching value in the specified column.
inherited
getList<R extends Row>(int column) → Iterable<R>
Retrieves rows of R from the specified column.
inherited
getParentRow<P extends Row>(int column) → P
Retrieves the parent row of the current row, based on the P and the column.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
readBlob(int column) → Blob
Reads a Blob from the specified column.
inherited
readGuid(int column) → Guid
Reads a Guid from the specified column.
inherited
readRow<R extends Row>(int column) → R
Reads a related row of type R from the specified column.
inherited
readString(int column) → String
Reads a string from the specified column.
inherited
readUint(int column) → int
Reads an unsigned integer from the specified column.
inherited
readUint16(int column, [int offset = 0]) → int
Reads an unsigned 16-bit integer from the specified column, with an optional offset.
inherited
readUint32(int column, [int offset = 0]) → int
Reads an unsigned 32-bit integer from the specified column, with an optional offset.
inherited
readUint64(int column, [int offset = 0]) → int
Reads an unsigned 64-bit integer from the specified column, with an optional offset.
inherited
readUint8(int column, [int offset = 0]) → int
Reads an unsigned 8-bit integer from the specified column, with an optional offset.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited