FixedArrayType class final

Represents a fixed-size array type.

Inheritance

Constructors

FixedArrayType(MetadataType element, int length)
const

Properties

code ElementType
The ElementType code corresponding to this metadata type.
no setteroverride
element MetadataType
The type of the elements stored in the array.
final
hashCode int
The hash code for this object.
no setteroverride
length int
The exact number of elements in the array.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override