nativeType property
The top-level native type encoding defined for this marshaling rule.
For example, this might be NATIVE_TYPE_I4, NATIVE_TYPE_LPWSTR, or NATIVE_TYPE_ARRAY for arrays.
Implementation
final NativeType nativeType;
The top-level native type encoding defined for this marshaling rule.
For example, this might be NATIVE_TYPE_I4, NATIVE_TYPE_LPWSTR, or NATIVE_TYPE_ARRAY for arrays.
final NativeType nativeType;