NamedArg constructor

const NamedArg({
  1. required String name,
  2. required MetadataValue value,
})

Creates a named argument with the given name and value.

The name must match a writable property or field defined on the attribute type.

Implementation

const NamedArg({required this.name, required MetadataValue value})
  : super(value);