PropertySig class final

Represents the signature of a property (essentially, the signature of its getter method) within metadata.

Inheritance

Constructors

PropertySig({required MetadataType returnType, CallingConvention callingConvention = .DEFAULT, List<MetadataType> types = const []})
Creates a PropertySig with the given callingConvention, returnType, and types.
const

Properties

callingConvention → CallingConvention
The method's calling convention.
finalinherited
hashCode → int
The hash code for this object.
no setteroverride
returnType → MetadataType
The return type of the method.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
types → List<MetadataType>
The list of parameter types for the method.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override