readRow<R extends Row> method

R readRow<R extends Row>(
  1. int column
)

Reads a related row of type R from the specified column.

The column represents the index in the table where the row is stored.

Implementation

R readRow<R extends Row>(int column) {
  final companion = Row.companion<R>();
  return companion.constructor(
    metadataIndex,
    readerIndex,
    readUint(column) - 1,
  );
}