StandAloneSignature class sealed

Represents a signature for a standalone method or local variable within metadata.

Implementers

Constructors

StandAloneSignature.localVar(List<MetadataType> locals)
Creates a LocalVarSig with the given list of locals, representing the types of local variables.
const
factory
StandAloneSignature.method({CallingConvention callingConvention, MetadataType returnType, List<MetadataType> types})
Creates a StandAloneMethodSig with the given callingConvention, returnType, and types.
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited