StringFormat enum

Defines the interpretation rules for string types.

Inheritance
Available extensions

Values

ansi → const StringFormat

Specifies that this type interprets an LPTSTR as ANSI.

unicode → const StringFormat

Specifies that this type interprets an LPTSTR as Unicode.

auto → const StringFormat

Specifies that this type interprets an LPTSTR automatically.

custom → const StringFormat

Specifies that the type has a non-standard encoding, as specified by CustomFormatMask.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<StringFormat>
A constant List of the values in this enum, in order of their declaration.