TypeDefOrRefTypeRef class final

A TypeDefOrRef representing a TypeRef.

Inheritance

Constructors

TypeDefOrRefTypeRef(TypeRef value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
The name of the underlying type.
no setteroverride
namespace String
The namespace of the underlying type.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value TypeRef
The underlying type reference.
final

Methods

encode() int
Encodes the coded index into its compressed integer representation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited