HasConstant class sealed

Represents a coded index for entities that can have constant values.

Implemented types
Implementers

Constructors

HasConstant.field(FieldIndex value)
Constructs a HasConstant referencing a Field.
const
factory
HasConstant.param(ParamIndex value)
Constructs a HasConstant referencing a Param.
const
factory
HasConstant.property(PropertyIndex value)
Constructs a HasConstant referencing a Property.
const
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

encode() → int
Encodes the coded index into its compressed integer representation.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited