HasCustomAttributeFile class final

A HasCustomAttribute representing a File.

Inheritance

Constructors

HasCustomAttributeFile(FileIndex value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → FileIndex
The index of the File.
final

Methods

encode() → int
Encodes the coded index into its compressed integer representation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override