HasCustomAttributeGenericParam class final

A HasCustomAttribute representing a GenericParam.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → GenericParamIndex
The index of the GenericParam.
final

Methods

encode() → int
Encodes the coded index into its compressed integer representation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override