ImplementationExportedType class final

A Implementation representing an ExportedType.

Inheritance

Constructors

ImplementationExportedType(ExportedTypeIndex value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → ExportedTypeIndex
The underlying exported type.
final

Methods

encode() → int
Encodes the coded index into its compressed integer representation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override