MemberRefParentMethodDef class final

A MemberRefParent representing a MethodDef.

Inheritance

Constructors

MemberRefParentMethodDef(MethodDefIndex value)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → MethodDefIndex
The index of the MethodDef.
final

Methods

encode() → int
Encodes the coded index into its compressed integer representation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override