CallConv enum
Represents the platform calling convention.
Values
- platformApi → const CallConv
-
Use the default platform calling convention.
For example, on Windows the default is StdCall and on Windows CE .NET it is Cdecl.
- cdecl → const CallConv
-
Use the Cdecl calling convention.
In this case, the caller cleans the stack. This enables calling functions with varargs (that is, functions that accept a variable number of parameters).
- stdcall → const CallConv
-
Use the StdCall calling convention.
In this case, the callee cleans the stack. This is the default convention for calling unmanaged functions with platform invoke.
- thiscall → const CallConv
-
Use the ThisCall calling convention.
In this case, the first parameter is the this pointer and is stored in register ECX. Other parameters are pushed on the stack. The ThisCall calling convention is used to call methods on classes exported from an unmanaged DLL.
- fastcall → const CallConv
-
Reserved.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited