SecurityAction enum
Specifies the security actions that can be performed using declarative security.
Values
- demand → const SecurityAction
-
All callers higher in the call stack are required to have been granted the permission specified by the current permission object.
const SecurityAction._(2) - assert$ → const SecurityAction
-
The calling code can access the resource identified by the current permission object, even if callers higher in the stack have not been granted permission to access the resource.
const SecurityAction._(3) - deny → const SecurityAction
-
The ability to access the resource specified by the current permission object is denied to callers, even if they have been granted permission t access it.
const SecurityAction._(4) - permitOnly → const SecurityAction
-
Only the resources specified by this permission object can be accessed, even if the code has been granted permission to access other resources.
const SecurityAction._(5) - linkDemand → const SecurityAction
-
The immediate caller is required to have been granted the specified permission.
const SecurityAction._(6) - inheritanceDemand → const SecurityAction
-
The derived class inheriting the class or overriding a method is required to have been granted the specified permission.
const SecurityAction._(7) - requestMinimum → const SecurityAction
-
The request for the minimum permissions required for code to run.
This action can only be used within the scope of the assembly.
const SecurityAction._(8) - requestOptional → const SecurityAction
-
The request for additional permissions that are optional (not required to run).
This request implicitly refuses all other permissions not specifically requested.
This action can only be used within the scope of the assembly.
const SecurityAction._(9) - requestRefused → const SecurityAction
-
The request that permissions that might be misused will not be granted to the calling code.
This action can only be used within the scope of the assembly.
const SecurityAction._(10)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
The value of the security action.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SecurityAction> - A constant List of the values in this enum, in order of their declaration.