TypeVisibility enum
Represents the visibility of a type to other types.
Values
- notPublic → const TypeVisibility
-
Specifies that the type is not in public scope.
- public → const TypeVisibility
-
Specifies that the type is in public scope.
- nestedPublic → const TypeVisibility
-
Specifies that the type is nested with public visibility.
- nestedPrivate → const TypeVisibility
-
Specifies that the type is nested with private visibility.
- nestedFamily → const TypeVisibility
-
Specifies that the type is nested with family visibility.
- nestedAssembly → const TypeVisibility
-
Specifies that the type is nested with assembly visibility.
- nestedFamilyANDAssembly → const TypeVisibility
-
Specifies that the type is nested with family and assembly visibility.
- nestedFamilyORAssembly → const TypeVisibility
-
Specifies that the type is nested with family or assembly visibility.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TypeVisibility> - A constant List of the values in this enum, in order of their declaration.