writePropertyMap method
Associates a TypeDef with the first property in its property list.
This must be called before writing any Property rows for the given
parent.
Implementation
void writePropertyMap({required TypeDefIndex parent}) {
final firstProperty = PropertyIndex(_tableStream[.property].length);
_tableStream[.propertyMap].add(
PropertyMap(parent: parent, propertyList: firstProperty),
);
}